==> hi16cod.db_2.0.1.tar.gz: hi16cod.db/man/hi16cod_dbconn.Rd <==
\name{hi16cod_dbconn}

\alias{hi16cod_dbconn}
\alias{hi16cod_dbfile}
\alias{hi16cod_dbschema}
\alias{hi16cod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hi16cod_dbconn()
  hi16cod_dbfile()
  hi16cod_dbschema(file="", show.indices=FALSE)
  hi16cod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hi16cod_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hi16cod_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hi16cod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hi16cod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hi16cod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hi16cod_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hi16cod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hi16cod_dbschema}: none (invisible \code{NULL}).

  \code{hi16cod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hi16cod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hi16cod_dbconn() was created with:
  dbConnect(SQLite(), dbname=hi16cod_dbfile(), cache_size=64000, synchronous=0)

  hi16cod_dbschema()

  hi16cod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hi16cod.db_2.18.0.tar.gz: hi16cod.db/man/hi16cod_dbconn.Rd <==

\name{hi16cod_dbconn}

\alias{hi16cod_dbconn}
\alias{hi16cod_dbfile}
\alias{hi16cod_dbschema}
\alias{hi16cod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hi16cod_dbconn()
  hi16cod_dbfile()
  hi16cod_dbschema(file="", show.indices=FALSE)
  hi16cod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hi16cod_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hi16cod_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hi16cod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hi16cod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hi16cod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hi16cod_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hi16cod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hi16cod_dbschema}: none (invisible \code{NULL}).

  \code{hi16cod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hi16cod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hi16cod_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hi16cod_dbfile(), cache_size=64000,
  synchronous=0)

  hi16cod_dbschema()

  hi16cod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
